@@ -1,8 +1,7 @@
 
 import com.beust.kobalt.plugin.java.javaCompiler
-import com.beust.kobalt.plugin.osgi.*
+import com.beust.kobalt.plugin.osgi.osgi
 import com.beust.kobalt.plugin.packaging.assemble
-import com.beust.kobalt.plugin.publish.bintray
 import com.beust.kobalt.project
 import org.apache.maven.model.Developer
 import org.apache.maven.model.License
@@ -13,7 +12,7 @@ val jcommander = project {
     name = "jcommander"
     group = "com.beust"
     artifactId = name
-    version = "1.71"
+    version = "1.78"
     description = "A Java library to parse command line options"
 
     dependenciesTest {
@@ -26,13 +25,8 @@ val jcommander = project {
         }
     }
 
-    bintray {
-        publish = true
-        sign = true
-    }
-
     javaCompiler {
-        args("-target", "1.7", "-source", "1.7")
+        args("-target", "1.8", "-source", "1.8", "-g", "-encoding", "utf-8")
     }
 
     osgi {}
