@@ -46,6 +46,11 @@ public @interface Parameter {
    */
   String description() default "";
 
+  /**
+   * Description of default value.
+   */
+  String defaultValueDescription() default "";
+
   /**
    * Whether this option is required.
    */
@@ -132,5 +137,11 @@ public @interface Parameter {
    * @return
    */
   int order() default -1;
+
+  /**
+   * If specified, the category name will be used to order the description of this parameter when usage() is invoked before the number order() is used.
+   * @return (default or specified) category name
+   */
+  String category() default "";
   
 }
